import request from '@/config/axios'

// 检查类型 VO
export interface CheckTypeVO {
  id: number // id
  name: string // 检查类型名
  value: number // 检查类型值
  readyNum: number // 允许准备中人数
  needDevReady: number // 需要设备领用
  callingColumn: number // 叫号列
  displayBarcode: number // 是否显示患者条码
  expenseRecognition: number // 是否需要确费
  timeslotBookNum: number // 时段预约规定人数
  timeslotReservedNum: number // 每时段预留人数
  affinityCheckTypes: number[] | null// 亲和的检查类型
}

// 检查类型 API
export const CheckTypeApi = {

  // 查询检查类型.简单列表
  getSimpleCheckTypeList: async () => {
    return await request.get({ url: `/ecg/check-type/list-simple-check-type` })
  },

  // 查询检查类型分页
  getCheckTypePage: async (params: any) => {
    return await request.get({ url: `/ecg/check-type/page`, params })
  },

  // 查询检查类型详情
  getCheckType: async (id: number) => {
    return await request.get({ url: `/ecg/check-type/get?id=` + id })
  },

  // 新增检查类型
  createCheckType: async (data: CheckTypeVO) => {
    return await request.post({ url: `/ecg/check-type/create`, data })
  },

  // 修改检查类型
  updateCheckType: async (data: CheckTypeVO) => {
    return await request.put({ url: `/ecg/check-type/update`, data })
  },

  // 删除检查类型
  deleteCheckType: async (id: number) => {
    return await request.delete({ url: `/ecg/check-type/delete?id=` + id })
  },

  // 导出检查类型 Excel
  exportCheckType: async (params) => {
    return await request.download({ url: `/ecg/check-type/export-excel`, params })
  }
}